==> python-trimesh-4.0.9-1-any.pkg.tar.zst: usr/lib/python3.11/site-packages/trimesh/__init__.py <==
"""
https://github.com/mikedh/trimesh
------------------------------------

Trimesh is a pure Python (2.7- 3.3+) library for loading and using triangular
meshes with an emphasis on watertight meshes. The goal of the library is to
provide a fully featured Trimesh object which allows for easy manipulation
and analysis, in the style of the Polygon object in the Shapely library.
"""
# avoid a circular import in trimesh.base
from . import (
    boolean,
    caching,
    collision,
    comparison,
    convex,
    creation,
    curvature,
    decomposition,
    geometry,
    graph,
    grouping,
    inertia,
    intersections,
    permutate,
    poses,
    primitives,
    proximity,
    ray,
    registration,
    remesh,
    repair,
    sample,
    smoothing,
    transformations,
    triangles,
    units,
    util,
)

# geometry objects
from .base import Trimesh

# general numeric tolerances
from .constants import tol

# loader functions
from .exchange.load import available_formats, load, load_mesh, load_path, load_remote
from .points import PointCloud
from .scene.scene import Scene
from .transformations import transform_points

# utility functions
from .util import unitize
from .version import __version__

try:
    # handle vector paths
    from . import path
except BaseException as E:
    # raise a useful error if path hasn't loaded
    from .exceptions import ExceptionWrapper

    path = ExceptionWrapper(E)

__all__ = [
    "PointCloud",
    "Trimesh",
    "Scene",
    "util",
    "__version__",
    "available_formats",
    "boolean",
    "bounds",
    "caching",
    "collision",
    "comparison",
    "convex",
    "creation",
    "curvature",
    "decomposition",
    "geometry",
    "graph",
    "grouping",
    "inertia",
    "intersections",
    "load",
    "load_mesh",
    "load_path",
    "load_remote",
    "nsphere",
    "path",
    "permutate",
    "poses",
    "primitives",
    "proximity",
    "ray",
    "registration",
    "remesh",
    "repair",
    "sample",
    "smoothing",
    "tol",
    "transform_points",
    "transformations",
    "triangles",
    "unitize",
    "units",
    "utilScene",
    "voxel",
]

==> python-trimesh-4.2.0-1-any.pkg.tar.zst: usr/lib/python3.11/site-packages/trimesh/__init__.py <==
"""
https://github.com/mikedh/trimesh
------------------------------------

Trimesh is a pure Python (2.7- 3.3+) library for loading and using triangular
meshes with an emphasis on watertight meshes. The goal of the library is to
provide a fully featured Trimesh object which allows for easy manipulation
and analysis, in the style of the Polygon object in the Shapely library.
"""

# avoid a circular import in trimesh.base
from . import (
    boolean,
    caching,
    collision,
    comparison,
    convex,
    creation,
    curvature,
    decomposition,
    exceptions,
    geometry,
    graph,
    grouping,
    inertia,
    intersections,
    permutate,
    poses,
    primitives,
    proximity,
    ray,
    registration,
    remesh,
    repair,
    sample,
    smoothing,
    transformations,
    triangles,
    units,
    util,
)

# geometry objects
from .base import Trimesh

# general numeric tolerances
from .constants import tol

# loader functions
from .exchange.load import available_formats, load, load_mesh, load_path, load_remote
from .points import PointCloud
from .scene.scene import Scene
from .transformations import transform_points

# utility functions
from .util import unitize
from .version import __version__

try:
    # handle vector paths
    from . import path
except BaseException as E:
    # raise a useful error if path hasn't loaded
    path = exceptions.ExceptionWrapper(E)


try:
    from . import voxel
except BaseException as E:
    # requires non-minimal imports
    voxel = exceptions.ExceptionWrapper(E)


__all__ = [
    "PointCloud",
    "Trimesh",
    "Scene",
    "util",
    "__version__",
    "available_formats",
    "boolean",
    "bounds",
    "caching",
    "collision",
    "comparison",
    "convex",
    "creation",
    "curvature",
    "decomposition",
    "geometry",
    "graph",
    "grouping",
    "inertia",
    "intersections",
    "load",
    "load_mesh",
    "load_path",
    "load_remote",
    "nsphere",
    "path",
    "permutate",
    "poses",
    "primitives",
    "proximity",
    "ray",
    "registration",
    "remesh",
    "repair",
    "sample",
    "smoothing",
    "tol",
    "transform_points",
    "transformations",
    "triangles",
    "unitize",
    "units",
    "utilScene",
    "voxel",
    "exceptions",
]
